;; Generated package description from dash.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "dash" "2.20.0.0.20250312.130713" "A modern list library for Emacs" '((emacs "24")) :commit "fcb5d831fc08a43f984242c7509870f30983c27c" :authors '(("Magnar Sveen" . "magnars@gmail.com")) :maintainer '("Basil L. Contovounesios" . "basil@contovou.net") :keywords '("extensions" "lisp") :url "https://github.com/magnars/dash.el")
